@@ -7,6 +7,7 @@ from django.db import migrations, models
 class Migration(migrations.Migration):
 
     dependencies = [
+        ('newsletter', '__first__'),
     ]
 
     operations = [
@@ -14,26 +15,18 @@ class Migration(migrations.Migration):
             name='CloudMailInformation',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('contact', models.ForeignKey(verbose_name='contact', to='newsletter.Contact')),
-                ('newsletter', models.ForeignKey(verbose_name='newsletter', to='newsletter.Newsletter')),
                 ('messageId', models.TextField(max_length=2048)),
-                ('message',  models.TextField(default='')),
+                ('message', models.TextField(default=b'')),
+                ('contact', models.ForeignKey(to='newsletter.Contact')),
+                ('newsletter', models.ForeignKey(to='newsletter.Newsletter')),
             ],
-            options={
-                'verbose_name': 'CloudMailInformation',
-                'verbose_name_plural': 'CloudMailInformation',
-            },
         ),
         migrations.CreateModel(
             name='NewsletterInformation',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('newsletter', models.ForeignKey(verbose_name='newsletter', to='newsletter.Newsletter')),
                 ('sync', models.BooleanField(default=True)),
+                ('newsletter', models.ForeignKey(to='newsletter.Newsletter', unique=True)),
             ],
-            options={
-                'verbose_name': 'NewsletterInformation',
-                'verbose_name_plural': 'NewsletterInformation',
-            },
         ),
     ]
