@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 10827 2018-03-11 15:11:03Z David $
+# $Id: models.py 11646 2019-07-01 01:31:33Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-11 23:11:03 +0800 (週日, 11 三月 2018) $
-# $Revision: 10827 $
+# $Author: Andy $
+# $Date: 2019-07-01 09:31:33 +0800 (週一, 01 七月 2019) $
+# $Revision: 11646 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -37,7 +37,7 @@ class CloudMailInformation(models.Model, BaseModelMixin):
 
 class NewsletterInformation(models.Model, BaseModelMixin):
 
-    newsletter = models.ForeignKey(Newsletter, unique=True)
+    newsletter = models.ForeignKey(Newsletter)
 
     sync = models.BooleanField(default=True)
 
