@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10891 2018-03-19 08:43:22Z David $
+# $Id: admin.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-19 16:43:22 +0800 (週一, 19 三月 2018) $
-# $Revision: 10891 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 from django import forms
 from django.contrib import admin
@@ -30,7 +30,7 @@ from Theophrastus.newsletter_extension.admin import NewsletterForm
 from Theophrastus.newsletter_extension.models import Header, Footer
 from Theophrastus.editor.forms import HeaderTinyMCEForm
 from Theophrastus.editor.forms import FooterTinyMCEForm
-from TinyMCEWidget import CustomTinyMCEWidget
+from .TinyMCEWidget import CustomTinyMCEWidget
 
 class NewsletterTinyMCEForm(NewsletterForm):
     def __init__(self, *args, **kwargs):
